/*
 * Copyright (c) 2011 by Intevation GmbH, Germany <info@intevation.de>
 *
 * This file is part of MXD2map.
 *
 * This program is free software under the LGPL (>=v2.1)
 * Read the file LICENCE.txt coming with the software for details
 * or visit http://www.gnu.org/licenses/ if it does not exist.
 *
 * MXD2map has been developed on behalf of the
 * Bundesamt fuer Seeschifffahrt und Hydrographie (BSH) in Hamburg
 * by Intevation GmbH.
 *
 * Authors:
 * Raimund Renkert <raimund.renkert@intevation.de>
 * Bjoern Schilberg <bjoern.schilberg@intevation.de>
 * Stephan Holl <stephan.holl@intevation.de>
 */

package de.intevation.mxd.reader;

import java.awt.Color;

import org.apache.log4j.Logger;

import com.esri.arcgis.display.ISymbol;
import com.esri.arcgis.display.ILineSymbol;
import com.esri.arcgis.display.SimpleLineSymbol;
import com.esri.arcgis.display.esriSimpleLineStyle;
import com.esri.arcgis.display.IRgbColor;
import com.esri.arcgis.display.RgbColor;

import org.w3c.dom.Element;
import java.io.IOException;

/**
 * Reads simple line symbol information.
 *
 * @author <a href="mailto:raimund.renkert@intevation.de">Raimund Renkert</a>
 */
public class SimpleLineSymbolReader
extends AbstractSymbolReader {

    /**
     * The logger.
     */
    private static final Logger logger =
        Logger.getLogger(SimpleLineSymbolReader.class);

    /**
     * Private member.
     */
    private SimpleLineSymbol symbol;

    /**
     * Constructor with symbol.
     *
     * @param symbol The symbol used to display lines.
     */
    public SimpleLineSymbolReader(ISymbol symbol)
    throws Exception {
        logger.debug("constructor()");
        if(symbol instanceof SimpleLineSymbol) {
            this.symbol = (SimpleLineSymbol)symbol;
        }
        else {
            throw new Exception("Not a SimpleLineSymbol!");
        }
    }

    /**
     * Constructor with symbol.
     *
     * @param symbol The symbol used to display lines.
     */
    public SimpleLineSymbolReader(ILineSymbol symbol)
    throws Exception {
        logger.debug("constructor()");
        if(symbol instanceof SimpleLineSymbol) {
            this.symbol = (SimpleLineSymbol)symbol;
        }
        else {
            throw new Exception("Not a SimpleLineSymbol!");
        }
    }

    /**
     * Reads the symbol attributes.
     *
     * @return The XML node.
     */
    public Element read() {
        logger.debug("read()");
        Element symbolElement = util.addSymbol(parent);

        try {
            symbolElement.setAttribute("name", symbol.getNameString());
        }
        catch(IOException ioe) {
            logger.warn("Could not read name. Setting name to \"default\"");
            symbolElement.setAttribute("name", "default");
        }

        try {
            if(symbol.getColor() instanceof IRgbColor) {
                IRgbColor color = (IRgbColor)symbol.getColor();
                Color c = new Color (
                    color.getRed(),
                    color.getGreen(),
                    color.getBlue());
                symbolElement.setAttribute("color", String.valueOf(c.getRGB()));
                symbolElement.setAttribute(
                    "transparency",
                    String.valueOf(c.getTransparency()));
            }
            else {
                RgbColor col = new RgbColor();
                col.setRGB(symbol.getColor().getRGB());
                Color c = new Color (
                    col.getRed(),
                    col.getGreen(),
                    col.getBlue());
                symbolElement.setAttribute("color", String.valueOf(c.getRGB()));
                symbolElement.setAttribute(
                    "transparency",
                    String.valueOf(c.getTransparency()));
            }
        }
        catch(IOException ioe) {
            logger.warn("Could not read color.");
        }

        try {
            symbolElement.setAttribute(
                "width",
                String.valueOf(symbol.getWidth()));
        }
        catch(IOException ioe) {
            logger.warn("Could not read width.");
        }

        int style;
        try {
           style = symbol.getStyle();
        }
        catch(IOException ioe) {
            logger.warn("Could not read line style.");
            style = -1;
        }
        switch(style) {
            case esriSimpleLineStyle.esriSLSSolid:
                    symbolElement.setAttribute("linestyle", "solid"); break;
            case esriSimpleLineStyle.esriSLSDash:
                    symbolElement.setAttribute("linestyle", "dash"); break;
            case esriSimpleLineStyle.esriSLSDot:
                    symbolElement.setAttribute("linestyle", "dot"); break;
            case esriSimpleLineStyle.esriSLSDashDot:
                    symbolElement.setAttribute("linestyle", "dashdot"); break;
            case esriSimpleLineStyle.esriSLSDashDotDot:
                    symbolElement.setAttribute("linestyle", "dashdotdot");
                    break;
            default: break;
        }

        symbolElement.setAttribute("type", "line");
        symbolElement.setAttribute("style", "simple");

        return symbolElement;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
